=====
Usage
=====
Most useful documentation in Jupyter notebooks included in the 'examples' folder.


But the basic gist is as follows.

.. code-block:: python

    import spylind
    # Define some Hamiltonians
    # solve
    # Plot

For the slightly lower level:

Main functions needed:

.. autofunction:: spylind.spylind.makeMESymb

.. autofunction:: spylind.spylind.seperate_DM_equation

.. autofunction:: spylind.spyIVP.ODESolver
